==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/General/hotkey/translations/hotkey_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Kısayolu Düzenle</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Atamak istediğiniz tuş kombinasyonuna basın</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>Genel Kısayol Eklentisi</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Genel Kısayol Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Genel Kısayol Eklentisi</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>Bu eklenti çokluortam tuşları veya genel tuş kombinasyonu desteği ekler</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>Oynat/Duraklat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>Göster/Gizle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Genel Kısayol Eklentisi Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Eylem</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
</context>
</TS>

==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/General/hotkey/translations/hotkey_plugin_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="tr_TR">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>Kısayolu Düzenle</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>Atamak istediğiniz tuş kombinasyonuna basın</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>Temizle</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>Genel Kısayol Eklentisi</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>Genel Kısayol Eklentisi Hakkında</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp Genel Kısayol Eklentisi</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>Bu eklenti çokluortam tuşları veya genel tuş kombinasyonu desteği ekler</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Yazan: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>Oynat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>Dur</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>Duraklat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>Oynat/Duraklat</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>Sonraki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>Önceki</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>Göster/Gizle</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Forward 5 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="52"/>
        <source>Rewind 5 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="53"/>
        <source>Jump to track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>Genel Kısayol Eklentisi Ayarları</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>Eylem</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>Kısayol</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>Sıfırla</translation>
    </message>
</context>
</TS>
